@@ -25,27 +25,17 @@
 
 require_once('version.php');
 require_once('libs/Smarty.class.php');
+require_once('bootstrap.php');
 error_reporting(E_ALL);
 
-define('SESSION_LOGIN_USER',          'loginUser');
-define('SESSION_LOGIN_USER_PASSWORD', 'md5pass');
-define('SESSION_LANG',                'lang');
-define('SESSION_MESSAGE',             'message');
-
 function versions()
 {
-    return array('3.2', '3.1', '3.0',
+    return array('3.3', '3.2', '3.1', '3.0',
                  '2.3', '2.2', '2.1', '2.0');
 }
 
 session_start();
 
-/**
- * Smarty Parameter
- */
-define('SMARTY_TEMPLATE_DIR', dirname(__FILE__) . '/templates' );
-define('SMARTY_COMPILE_DIR', dirname(__FILE__) . '/templates_c' );
-
 /**
  * Initialize Smartry
  */
@@ -269,13 +259,13 @@ function NodeStandby($num)
         return -1;
     }
 
-    $res = pg_query($conn, 'SELECT pg_is_in_recovery()');
-    if (!pg_result_status($res) == PGSQL_TUPLES_OK) {
+    $result = pg_query($conn, 'SELECT pg_is_in_recovery()');
+    if (!pg_result_status($result) == PGSQL_TUPLES_OK) {
         @pg_close($conn);
         return -1;
     }
 
-    $rr = pg_fetch_array($res);
+    $rr = pg_fetch_array($result);
 
     if ($rr[0][0] == 't') {
         $r = 1;
@@ -283,7 +273,7 @@ function NodeStandby($num)
         $r = 0;
     }
 
-    @pg_free_result($res);
+    @pg_free_result($result);
     @pg_close($conn);
     return $r;
 }
@@ -308,13 +298,13 @@ function conStr($num, $mode = NULL)
                     $params['health_check_password'] : NULL;
     }
 
-    // backkend info
+    // backend info
     $params = readConfigParams(array('backend_hostname',
                                      'backend_port',
                                      'backend_weight'));
     $conStr = array();
     if ($params['backend_hostname'][$num] != '') {
-        $conStr[] = "host={$params['backend_hostname'][$num]} ";
+        $conStr[] = "host='{$params['backend_hostname'][$num]}'";
     }
     $conStr[] = "port='{$params['backend_port'][$num]}'";
     $conStr[] = "dbname='template1'";
@@ -482,6 +472,19 @@ function readConfigParams($paramList = FALSE)
                 $num = str_replace('other_wd_port', '', $key);
                 $configParam['other_wd_port'][$num] = $value;
 
+            // params about watchdog heartbeat
+            } elseif (preg_match("/^heartbeat_destination_port/", $key)) {
+                $num = str_replace('heartbeat_destination_port', '', $key);
+                $configParam['heartbeat_destination_port'][$num] = $value;
+
+            } elseif (preg_match("/^heartbeat_destination/", $key)) {
+                $num = str_replace('heartbeat_destination', '', $key);
+                $configParam['heartbeat_destination'][$num] = str_replace("'", "", $value);
+
+            } elseif (preg_match("/^heartbeat_device/", $key)) {
+                $num = str_replace('heartbeat_device', '', $key);
+                $configParam['heartbeat_device'][$num] = str_replace("'", "", $value);
+
             } else {
                 $configParam[$key] = str_replace("'", "", $value);
             }
@@ -494,14 +497,17 @@ function readConfigParams($paramList = FALSE)
                 $results[$key] = $configParam[$key];
             } else {
                 require_once('definePgpoolConfParam.php');
-                if(!preg_match("/^backend_hostname/",       $key) &&
-                   !preg_match("/^backend_port/",           $key) &&
-                   !preg_match("/^backend_weight/",         $key) &&
-                   !preg_match("/^backend_data_directory/", $key) &&
-                   !preg_match("/^backend_flag/",           $key) &&
-                   !preg_match("/^other_pgpool_hostname/",  $key) &&
-                   !preg_match("/^other_pgpool_port/",      $key) &&
-                   !preg_match("/^other_wd_port/",          $key)
+                if(!preg_match("/^backend_hostname/",           $key) &&
+                   !preg_match("/^backend_port/",               $key) &&
+                   !preg_match("/^backend_weight/",             $key) &&
+                   !preg_match("/^backend_data_directory/",     $key) &&
+                   !preg_match("/^backend_flag/",               $key) &&
+                   !preg_match("/^other_pgpool_hostname/",      $key) &&
+                   !preg_match("/^other_pgpool_port/",          $key) &&
+                   !preg_match("/^other_wd_port/",              $key) &&
+                   !preg_match("/^heartbeat_destination/",      $key) &&
+                   !preg_match("/^heartbeat_destination_port/", $key) &&
+                   !preg_match("/^heartbeat_device/",           $key)
                    )
                 {
                     if (isset($configParam[$key])) {
@@ -552,6 +558,23 @@ function paramExists($param)
     switch ($param) {
         /* Add */
 
+        // params added in 3.3
+        case 'clear_memqcache_on_escalation':
+        case 'heartbeat_destination':
+        case 'heartbeat_destination_port':
+        case 'heartbeat_device':
+        case 'wd_authkey':
+        case 'wd_escalation_command':
+        case 'wd_lifecheck_method':
+        case 'wd_heartbeat_port':
+        case 'wd_heartbeat_keepalive':
+        case 'wd_heartbeat_deadtime':
+        case 'wd_lifecheck_dbname':
+        case 'wd_lifecheck_user':
+        case 'wd_lifecheck_password':
+            $add_version = 3.3;
+            break;
+
         // params added in 3.2
         case 'health_check_max_retries':
         case 'health_check_retry_delay':
@@ -657,4 +680,53 @@ function paramExists($param)
     }
     return FALSE;
 }
-?>
+
+/* Get if loginUser is super user */
+function isSuperUser($user_name)
+{
+    if (DoesPgpoolPidExist() && isset($_SESSION[SESSION_IS_SUPER_USER])) {
+        return $_SESSION[SESSION_IS_SUPER_USER];
+    }
+    $conn = @pg_connect(conStrPgpool());
+
+    if ($conn == FALSE) {
+        @pg_close($conn);
+        return NULL;
+    }
+
+    $result = pg_query($conn, "SELECT usesuper FROM pg_user WHERE usename = '{$user_name}'");
+
+   if (!pg_result_status($result) == PGSQL_TUPLES_OK) {
+        @pg_close($conn);
+        return NULL;
+    }
+
+    $rr = pg_fetch_array($result);
+    $rtn = (isset($rr['usesuper']) && $rr['usesuper'] == 't');
+
+    @pg_free_result($result);
+    @pg_close($conn);
+
+     $_SESSION[SESSION_IS_SUPER_USER] = $rtn;
+    return $rtn;
+}
+
+function conStrPgpool()
+{
+    $params = readConfigParams(array('port'));
+    $conStr[] = "port='{$params['port']}'";
+    $conStr[] = "dbname='template1'";
+    $conStr[] = "user='{$_SESSION[SESSION_LOGIN_USER]}'";
+    $conStr[] = "password='{$_SESSION[SESSION_LOGIN_USER_PASSWORD]}'";
+
+    $conStr = implode($conStr, ' ');
+    return $conStr;
+}
+
+/* for debug */
+function pr($array)
+{
+    echo '<pre>';
+    print_r($array);
+    echo '</pre>';
+}
